@@ -238,30 +238,32 @@ REGEX_QUICK_EMAIL = re.compile(r"""
     >               # Match ">" once.""", re.VERBOSE)
 
 REGEX_QUICK_LINK = re.compile(r"""
-    (?<!\\)             # Ensure there's no escaping backslash.
-    <                   # Match "<" once.
-    (                   # CAPTURE GROUP (1) | Open capture group.
-        https?          # Match either "http" or "https".
-        ://             # Match "://" once.
-        (?:             # Open non-capturing group.
-            -           # Match "-" once.
-            \.          # Match "." once.
-        )?              # Close non-capturing group and match it either 0 or 1
-                        # times.
-        (?:             # Open non-capturing group.
-            [^\s/?.#-]+ # Match any character that is not a whitespace, "/",
-                        # "?", ".", "#", or "-", between 1 and ∞ times.
-            \.?         # Match ".", either 0 or 1 times.
-        )+              # Close non-capturing group and match it between 1 and
-                        # ∞ times.
-        (?:             # Open non-capturing group.
-            /           # Match "/" once.
-            [^\s]*      # Match any character that is not a whitespace, between
-                        # 0 and ∞ times.
-        )?              # Close non-capturing group and match it either 0 or 1
-                        # times.
-    )                   # CAPTURE GROUP (1) | Close and match capture group.
-    >                   # Match ">" once.""", re.VERBOSE)
+    (?<!\\)                 # Ensure there's no escaping backslash.
+    <                       # Match "<" once.
+    (                       # CAPTURE GROUP (1) | Open capture group.
+        https?              # Match either "http" or "https".
+        ://                 # Match "://" once.
+        (?:                 # Open non-capturing group.
+            -               # Match "-" once.
+            \.              # Match "." once.
+        )?                  # Close non-capturing group and match it either 0
+                            # or 1 times.
+        (?:                 # Open non-capturing group.
+            [^\s/?.#->]+    # Match any character that is not a whitespace,
+                            # "/", "?", ".", "#", or "-", between 1 and ∞
+                            # times.
+            \.?             # Match ".", either 0 or 1 times.
+        )+                  # Close non-capturing group and match it between 1
+                            # and ∞ times.
+        (?:                 # Open non-capturing group.
+            /               # Match "/" once.
+            [^\s]*          # Match any character that is not a whitespace,
+                            # between 0 and ∞ times.
+        )?                  # Close non-capturing group and match it either 0
+                            # or 1 times.
+    )                       # CAPTURE GROUP (1) | Close and match capture
+                            # group.
+    >                       # Match ">" once.""", re.VERBOSE)
 
 REGEX_UNORDERED_LIST = re.compile(r"""
     (\s+)?  # CAPTURE GROUP (1) | Match between 1 and ∞ whitespaces, as many
